/*
 * Copyright (c) 2015 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000
 *
 * de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Diese Datei ist Teil von de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000 ist Freie Software: Sie können es unter den Bedingungen
 *  der GNU General Public License, wie von der Free Software Foundation,
 *  Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 *  veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000 wird in der Hoffnung, dass es nützlich sein wird, aber
 *  OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 *  Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 *  Siehe die GNU General Public License für weitere Details.
 *
 *  Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 *  Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */

package de.bsvrz.kex.tls.osi7.conversion;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.kex.tls.osi7.*;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Umsetungsmodul für die FG 3, Datentypen 35-72 gemäß TLS. Wird diese Klasse angegeben, so KANN dieses De ALLE Fg 3
 * Typen (also in erster Linie zum Testen bzw. um bei einer unbkannten De den Antworttyp zu ermitteln.
 * <p>
 * Erweiterung: unterstützt auch nachgelieferte Telegramme (Standard ID+32)
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @version $Revision$ / $Date$ / ($Author$)
 */

public class Fg003Typ000 extends Fg003Default {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Sonstige ---------------------------------------------------------------
	/** DebugLogger für Debug-Ausgaben */
	private static final Debug debug = Debug.getLogger();
// Private ----------------------------------------------------------------
	/**
	 * Tabelle, in der das Verhalten beim Empfang von Attributgruppen eingetragen wird. Jede Tabellenzeile hat folgenden
	 * Aufbau:
	 * <pre>
	 * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
	 * z.B.
	 * "atg.tlsGloKanalSteuerung", "asp.parameterSoll", "1", "29", "2", "typ.deLve"
	 * </pre>
	 * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
	 * Empfangsanmeldung als Empfänger.</li> <li> In der Methode {@link #update} wird für jede zur
	 * Attributgruppen/Aspket-Kombination passende Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag
	 * wie folgt gebildet wird (hier für den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspParameterSoll(ResultData)</code><br>
	 * Dabei enthält <code>ResultData</code> die Daten der zu verarbeitenden ATG/ASP-Kombination.</li> <li> Für jede
	 * Attributguppen/Aspekt Kombination erfolgt eine Empfangsanmeldung als Empfänger. Sind mehrere passende Eintrage
	 * vorhanden, werden entsprechend mehrere Methodenaufrufe durchgeführt. Dadurch können mehrere ATG/ASP-Kombinationen in
	 * einen De-Block abgebildet werden (z.B. protokollnahe TLS-Attributgruppe und Attributgruppe eines Fachmodells):</li>
	 * <li> Ein Eintrag von "255" entspricht dabei einer "Wildcard" (passt immer). </ul>
	 */
	private final Object[][] davToTls = new Object[][]{
			// Attributgruppe, Aspekt, Fg, Typ, Id, ObjektTyp
	};

	/**
	 * Tabelle, in der das Verhalten beim Empfang von TLS De-Blöcken eingetragen wird. Jede Tabellenzeile hat folgenden
	 * Aufbau:
	 * <pre>
	 * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
	 * z.B.
	 * "atg.tlsGloKanalSteuerung", "asp.tlsAntwort", "1", "29", "2", "typ.deLve"
	 * </pre>
	 * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
	 * Sendeanmeldung als Quelle.</li> <li> In der Methode {@link #processDeBlock} wird für jede zum De-Block passende
	 * Fg/Id/Typ-Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag wie folgt gebildet wird (hier für
	 * den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspTlsAntwort(DeBlock, Data,
	 * DataDescription)</code><br> Dabei enthält der <code>deBlock</code> die Daten des zu verarbeitenden De-Blocks und
	 * <code>data</code> ein Datenobjekt der passenden Attributgruppen/Aspekt-Kombination, welchem direkt die Inhalte des
	 * De-Blocks zugewiesen werden können.<code>DataDescription</code> enthält die passende {@link
	 * DataDescription} für die zu sendenden Daten.</li> <li> Für jede Attributguppen/Aspekt
	 * Kombination erfolgt eine Sendeanmeldung als Quelle. Sind mehrere passende Eintrage vorhanden, werden entsprechend
	 * mehrere Methodenaufrufe durchgeführt. Dadurch kann ein De-Block mehrfach ausgewert und an verschiedene
	 * Attributgruppen weitergerleitet werden (z.B. protokollnahe TLS-Attributgruppe und Attributgruppe eine
	 * Fachmodells):</li> <li> Ein Eintrag von "255" entspricht dabei einer "Wildcard" (passt immer). </ul>
	 */

	private final Object[][] tlsToDav = new Object[][]{
			{"atg.tlsUfdErgebnisMeldungTyp35", "asp.tlsAntwort", "3", "35", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTyp35", "asp.tlsAntwort", "3", "35", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungLuftTemperaturLT", "asp.tlsAntwort", "3", "48", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungLuftTemperaturLT", "asp.tlsAntwort", "3", "48", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnOberFlächenTemperaturFBT", "asp.tlsAntwort", "3", "49", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnOberFlächenTemperaturFBT", "asp.tlsAntwort", "3", "49", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnFeuchteFBF", "asp.tlsAntwort", "3", "50", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnFeuchteFBF", "asp.tlsAntwort", "3", "50", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnOberFläche", "asp.tlsAntwort", "3", "51", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnOberFläche", "asp.tlsAntwort", "3", "51", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungRestSalzRS", "asp.tlsAntwort", "3", "52", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungRestSalzRS", "asp.tlsAntwort", "3", "52", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlagsIntensitätNI", "asp.tlsAntwort", "3", "53", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlagsIntensitätNI", "asp.tlsAntwort", "3", "53", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungLuftDruckLD", "asp.tlsAntwort", "3", "54", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungLuftDruckLD", "asp.tlsAntwort", "3", "54", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungRelativeLuftFeuchteRLF", "asp.tlsAntwort", "3", "55", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungRelativeLuftFeuchteRLF", "asp.tlsAntwort", "3", "55", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWindRichtungWR", "asp.tlsAntwort", "3", "56", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWindRichtungWR", "asp.tlsAntwort", "3", "56", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWindGeschwindigkeitMittelWertWGM", "asp.tlsAntwort", "3", "57", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWindGeschwindigkeitMittelWertWGM", "asp.tlsAntwort", "3", "57", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungSchneeHöheSH", "asp.tlsAntwort", "3", "58", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungSchneeHöheSH", "asp.tlsAntwort", "3", "58", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnGlätteFBG", "asp.tlsAntwort", "3", "59", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungFahrbahnGlätteFBG", "asp.tlsAntwort", "3", "59", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungSichtWeiteSW", "asp.tlsAntwort", "3", "60", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungSichtWeiteSW", "asp.tlsAntwort", "3", "60", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungHelligkeitHK", "asp.tlsAntwort", "3", "61", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungHelligkeitHK", "asp.tlsAntwort", "3", "61", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlagsMengeNMAspTlsAntwort", "asp.tlsAntwort", "3", "62", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlagsMengeNMAspTlsAntwort", "asp.tlsAntwort", "3", "62", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlag", "asp.tlsAntwort", "3", "63", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlag", "asp.tlsAntwort", "3", "63", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWindGeschwindigkeitSpitzenWertWGS", "asp.tlsAntwort", "3", "64", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWindGeschwindigkeitSpitzenWertWGS", "asp.tlsAntwort", "3", "64", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungGefrierTemperaturGT", "asp.tlsAntwort", "3", "65", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungGefrierTemperaturGT", "asp.tlsAntwort", "3", "65", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTaupunktTemperaturTPT", "asp.tlsAntwort", "3", "66", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTaupunktTemperaturTPT", "asp.tlsAntwort", "3", "66", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTemperaturInTiefe1TT1", "asp.tlsAntwort", "3", "67", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTemperaturInTiefe1TT1", "asp.tlsAntwort", "3", "67", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTemperaturInTiefe2TT2", "asp.tlsAntwort", "3", "68", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTemperaturInTiefe2TT2", "asp.tlsAntwort", "3", "68", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTemperaturInTiefe3TT3", "asp.tlsAntwort", "3", "69", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungTemperaturInTiefe3TT3", "asp.tlsAntwort", "3", "69", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungZustandDerFahrbahnOberFlächeFBZ", "asp.tlsAntwort", "3", "70", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungZustandDerFahrbahnOberFlächeFBZ", "asp.tlsAntwort", "3", "70", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlagsArtNS", "asp.tlsAntwort", "3", "71", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungNiederschlagsArtNS", "asp.tlsAntwort", "3", "71", "36", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWasserFilmDickeWFD", "asp.tlsAntwort", "3", "72", "4", "typ.deUfd"},
			{"atg.tlsUfdErgebnisMeldungWasserFilmDickeWFD", "asp.tlsAntwort", "3", "72", "36", "typ.deUfd"}
	};

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Objekterzeugung mit Anmeldung der globalen und lokalen Umsetzungseinträge
	 *
	 * @param daf DaV
	 * @param eak Eak
	 * @param de De
	 */
	public Fg003Typ000(ClientDavInterface daf, Eak eak, De de) {
		super(daf, eak, de);
		subscribeAllData(tlsToDav, davToTls);
	}

// ------------------------------------------------------------------------
// SONSTIGE METHODEN
// ------------------------------------------------------------------------

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ035Id004AtgTlsUfdErgebnisMeldungTyp35AspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ035Id036AtgTlsUfdErgebnisMeldungTyp35AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ035Id004AtgTlsUfdErgebnisMeldungTyp35AspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ048Id004AtgTlsUfdErgebnisMeldungLuftTemperaturLTAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ048Id036AtgTlsUfdErgebnisMeldungLuftTemperaturLTAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ048Id004AtgTlsUfdErgebnisMeldungLuftTemperaturLTAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ049Id004AtgTlsUfdErgebnisMeldungFahrbahnOberFlächenTemperaturFBTAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ049Id036AtgTlsUfdErgebnisMeldungFahrbahnOberFlächenTemperaturFBTAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ049Id004AtgTlsUfdErgebnisMeldungFahrbahnOberFlächenTemperaturFBTAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ050Id004AtgTlsUfdErgebnisMeldungFahrbahnFeuchteFBFAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ050Id036AtgTlsUfdErgebnisMeldungFahrbahnFeuchteFBFAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ050Id004AtgTlsUfdErgebnisMeldungFahrbahnFeuchteFBFAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ051Id004AtgTlsUfdErgebnisMeldungFahrbahnOberFlächeAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ051Id036AtgTlsUfdErgebnisMeldungFahrbahnOberFlächeAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ051Id004AtgTlsUfdErgebnisMeldungFahrbahnOberFlächeAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ052Id004AtgTlsUfdErgebnisMeldungRestSalzRSAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ052Id036AtgTlsUfdErgebnisMeldungRestSalzRSAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ052Id004AtgTlsUfdErgebnisMeldungRestSalzRSAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ053Id004AtgTlsUfdErgebnisMeldungNiederschlagsIntensitätNIAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ053Id036AtgTlsUfdErgebnisMeldungNiederschlagsIntensitätNIAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ053Id004AtgTlsUfdErgebnisMeldungNiederschlagsIntensitätNIAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ054Id004AtgTlsUfdErgebnisMeldungLuftDruckLDAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ054Id036AtgTlsUfdErgebnisMeldungLuftDruckLDAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ054Id004AtgTlsUfdErgebnisMeldungLuftDruckLDAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ055Id004AtgTlsUfdErgebnisMeldungRelativeLuftFeuchteRLFAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ055Id036AtgTlsUfdErgebnisMeldungRelativeLuftFeuchteRLFAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ055Id004AtgTlsUfdErgebnisMeldungRelativeLuftFeuchteRLFAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ056Id004AtgTlsUfdErgebnisMeldungWindRichtungWRAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ056Id036AtgTlsUfdErgebnisMeldungWindRichtungWRAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ056Id004AtgTlsUfdErgebnisMeldungWindRichtungWRAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ057Id004AtgTlsUfdErgebnisMeldungWindGeschwindigkeitMittelWertWGMAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ057Id036AtgTlsUfdErgebnisMeldungWindGeschwindigkeitMittelWertWGMAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ057Id004AtgTlsUfdErgebnisMeldungWindGeschwindigkeitMittelWertWGMAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ058Id004AtgTlsUfdErgebnisMeldungSchneeHöheSHAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ058Id036AtgTlsUfdErgebnisMeldungSchneeHöheSHAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ058Id004AtgTlsUfdErgebnisMeldungSchneeHöheSHAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ059Id004AtgTlsUfdErgebnisMeldungFahrbahnGlätteFBGAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ059Id036AtgTlsUfdErgebnisMeldungFahrbahnGlätteFBGAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ059Id004AtgTlsUfdErgebnisMeldungFahrbahnGlätteFBGAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ060Id004AtgTlsUfdErgebnisMeldungSichtWeiteSWAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ060Id036AtgTlsUfdErgebnisMeldungSichtWeiteSWAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ060Id004AtgTlsUfdErgebnisMeldungSichtWeiteSWAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ061Id004AtgTlsUfdErgebnisMeldungHelligkeitHKAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ061Id036AtgTlsUfdErgebnisMeldungHelligkeitHKAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ061Id004AtgTlsUfdErgebnisMeldungHelligkeitHKAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ062Id004AtgTlsUfdErgebnisMeldungNiederschlagsMengeNMAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ062Id036AtgTlsUfdErgebnisMeldungNiederschlagsMengeNMAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ062Id004AtgTlsUfdErgebnisMeldungNiederschlagsMengeNMAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ063Id036AtgTlsUfdErgebnisMeldungNiederschlagAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ063Id036AtgTlsUfdErgebnisMeldungNiederschlagAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ063Id004AtgTlsUfdErgebnisMeldungNiederschlagAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ064Id004AtgTlsUfdErgebnisMeldungWindGeschwindigkeitSpitzenWertWGSAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ064Id036AtgTlsUfdErgebnisMeldungWindGeschwindigkeitSpitzenWertWGSAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ064Id004AtgTlsUfdErgebnisMeldungWindGeschwindigkeitSpitzenWertWGSAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ065Id004AtgTlsUfdErgebnisMeldungGefrierTemperaturGTAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ065Id036AtgTlsUfdErgebnisMeldungGefrierTemperaturGTAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ065Id004AtgTlsUfdErgebnisMeldungGefrierTemperaturGTAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ066Id004AtgTlsUfdErgebnisMeldungTaupunktTemperaturTPTAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ066Id036AtgTlsUfdErgebnisMeldungTaupunktTemperaturTPTAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ066Id004AtgTlsUfdErgebnisMeldungTaupunktTemperaturTPTAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ067Id004AtgTlsUfdErgebnisMeldungTemperaturInTiefe1TT1AspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ067Id036AtgTlsUfdErgebnisMeldungTemperaturInTiefe1TT1AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ067Id004AtgTlsUfdErgebnisMeldungTemperaturInTiefe1TT1AspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ068Id004AtgTlsUfdErgebnisMeldungTemperaturInTiefe2TT2AspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ068Id036AtgTlsUfdErgebnisMeldungTemperaturInTiefe2TT2AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ068Id004AtgTlsUfdErgebnisMeldungTemperaturInTiefe2TT2AspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ069Id004AtgTlsUfdErgebnisMeldungTemperaturInTiefe3TT3AspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ069Id036AtgTlsUfdErgebnisMeldungTemperaturInTiefe3TT3AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ069Id004AtgTlsUfdErgebnisMeldungTemperaturInTiefe3TT3AspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ070Id004AtgTlsUfdErgebnisMeldungZustandDerFahrbahnOberFlächeFBZAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ070Id036AtgTlsUfdErgebnisMeldungZustandDerFahrbahnOberFlächeFBZAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ070Id004AtgTlsUfdErgebnisMeldungZustandDerFahrbahnOberFlächeFBZAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ071Id004AtgTlsUfdErgebnisMeldungNiederschlagsArtNSAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ071Id036AtgTlsUfdErgebnisMeldungNiederschlagsArtNSAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ071Id004AtgTlsUfdErgebnisMeldungNiederschlagsArtNSAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}

	/**
	 * Entspricht {@link de.bsvrz.kex.tls.osi7.conversion.Fg003Typ000#Fg003Typ072Id004AtgTlsUfdErgebnisMeldungWasserFilmDickeWFDAspTlsAntwort(DeBlock,
	 *Data,DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
	 *
	 * @param deBlock         Der zu bearbeitende De-Block.
	 * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
	 * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
	 *
	 * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten. @return
	 *         Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
	 */
	public ResultData Fg003Typ072Id036AtgTlsUfdErgebnisMeldungWasserFilmDickeWFDAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
		// Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
		ResultData resultData = Fg003Typ072Id004AtgTlsUfdErgebnisMeldungWasserFilmDickeWFDAspTlsAntwort(deBlock, data, dataDescription);
		return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
	}
}
